==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "İşlemler",
    "Error loading activities" : "İşlemler yüklenirken bir sorun çıktı",
    "No activities" : "Henüz bir işlem yok",
    "Load more activities" : "Diğer işlemleri yükle",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "{name} (invisible)" : "{name} (görüntülenmez)",
    "{name} (restricted)" : "{name} (kısıtlı)",
    "in {path}" : "{path} içinde",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşım gibi işlemler görüntülenir",
    "There are no events for this filter" : "Bu süzgeçte herhangi bir işlem yok",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "Activity" : "İşlem",
    "Personal activity feed for %s" : "%s kişisel işlem akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "All activities" : "Tüm işlemler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "Activity notification" : "İşlem bildirimi",
    ", " : ", ",
    "%s and %s" : "%s ve %s",
    "Hello %s," : "Merhaba %s,",
    "You are receiving this email because the following things happened at %s" : "Bu e-posta %s üzerinde aşağıdaki işlemlerin yapıldığını bildirmek üzere gönderilmiştir:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ve %n diğer","* ve %n diğer"],
    "List your own actions in the stream" : "Akıştaki kendi işlemlerinizi görüntüleyin",
    "Notify about your own actions via email" : "Kendi işlemleriniz e-posta ile bildirilsin",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send emails:" : "E-posta gönderimi:",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Activity feed" : "İşlem akışı",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "No activity yet" : "Henüz bir işlem yok",
    "No more events to load" : "Yüklenecek başka bir işlem yok",
    "Files" : "Dosyalar"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "İşlemler",
    "An error occurred while loading activities" : "İşlemler yüklenirken bir sorun çıktı",
    "No activity yet" : "Henüz bir işlem yapılmamış",
    "Load more activities" : "Diğer işlemleri yükle",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "{name} (invisible)" : "{name} (görüntülenmez)",
    "{name} (restricted)" : "{name} (kısıtlı)",
    "in {path}" : "{path} içinde",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşım gibi işlemler görüntülenir",
    "There are no events for this filter" : "Bu süzgeçte herhangi bir işlem yok",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "Personal activity feed for %s" : "%s kişisel işlem akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Settings have been updated." : "Ayarlar güncellendi",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "All activities" : "Tüm işlemler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "Hello %s" : "Merhaba %s",
    "Hello %s," : "Merhaba %s,",
    "There was some activity at %s" : "%s üzerinde bazı işlemler yapıldı",
    "_and %n more _::_and %n more _" : ["ve %n diğer","ve %n diğer"],
    "Activity notification" : "İşlem bildirimi",
    ", " : ", ",
    "%s and %s" : "%s ve %s",
    "Activity" : "İşlem",
    "Activity feed" : "İşlem akışı",
    "Configure the default activity settings for new users." : "Yeni kullanıcılar için varsayılan işlem ayarlarını yapın.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "E-posta bildirimlerinin gönderilmesini ve uygulama işlem akışında yer almasını istediğiniz işlemleri seçin.",
    "List your own actions in the stream" : "Akıştaki kendi işlemlerinizi görüntüleyin",
    "Notify about your own actions via email" : "Kendi işlemleriniz e-posta ile bildirilsin",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send emails:" : "E-posta gönderimi:",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Settings" : "Ayarlar",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "No more events to load" : "Yüklenecek başka bir işlem yok",
    "Files" : "Dosyalar",
    "Error loading activities" : "İşlemler yüklenirken sorun çıktı",
    "No activities" : "Henüz bir işlem yapılmamış",
    "You are receiving this email because the following things happened at %s" : "Bu e-posta %s üzerinde aşağıdaki işlemlerin yapıldığını bildirmek üzere gönderilmiştir:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ve %n diğer","* ve %n diğer"]
},
"nplurals=2; plural=(n > 1);");
